//
// anyRemote
// a wi-fi or bluetooth remote for your PC.
//
// Copyright (C) 2006-2016 Mikhail Fedotov <anyremote@mail.ru>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#ifndef _PR_SOCKET_H_
#define _PR_SOCKET_H_

#include "peer.h"

int  socketFD      (ConnectInfo* conn);
int  socketOpen    (ConnectInfo* conn);
int  socketListen  (ConnectInfo* conn);
//int  socketSetup   (ConnectInfo* conn);
int  socketAccept  (ConnectInfo* conn);
int  socketWrite   (ConnectInfo* conn, const dMessage* msg);
void socketClose   (ConnectInfo* conn, int final);
void socketReset   (ConnectInfo* conn);

#endif
